layout: Modify the layout of a plotly visualization

View source: R/layout.R

layoutR Documentation

Modify the layout of a plotly visualization

Description

Modify the layout of a plotly visualization

Usage

layout(p, ..., data = NULL)

Arguments

p

A plotly object.

...

Arguments to the layout object. For documentation, see https://plotly.com/r/reference/layout/

data

A data frame to associate with this layout (optional). If not provided, arguments are evaluated using the data frame in plot_ly().

Author(s)

Carson Sievert


plotly documentation built on July 22, 2026, 9:06 a.m.