Learn R Programming

plotly (version 3.4.1)

embed_notebook: Embed a plotly figure as an iframe into a IPython Notebook

Description

Embed a plotly figure as an iframe into a IPython Notebook

Usage

embed_notebook(x, width = NULL, height = NULL,
  file = paste0("plotlyJupyterHTML/", digest::digest(Sys.time()), ".html"))

Arguments

x
a plotly object
width
attribute of the iframe. If NULL, the width in plot_ly is used. If that is also NULL, '100%' is the default.
height
attribute of the iframe. If NULL, the height in plot_ly is used. If that is also NULL, '400px' is the default.
file
a filename for saving the standalone HTML (only used if x is a non-figure object)