Learn R Programming

plotly (version 3.4.1)

plotly_POST: Create/Modify plotly graphs

Description

Create and modify graphs on your plotly account via plotly's REST API https://plot.ly/rest/

Usage

plotly_POST(x, filename = NULL, fileopt = "overwrite",
  sharing = c("public", "private", "secret"))

Arguments

x
either a ggplot object, a plotly object, or a list.
filename
character string describing the name of the plot in your plotly account. Use / to specify directories. If a directory path does not exist it will be created. If this argument is not specified and the title of the plot exists, that will be used for the
fileopt
character string describing whether to create a "new" plotly, "overwrite" an existing plotly, "append" data to existing plotly, or "extend" it.
sharing
If 'public', anyone can view this graph. It will appear in your profile and can appear in search engines. You do not need to be logged in to Plotly to view this chart. If 'private', only you can view this plot. It will not appear in the Plotly feed, your

Value

  • An R object created by mapping the JSON content of the plotly API response to its R equivalent.

See Also

plot_ly, signup

Examples

Run this code
p <- plot_ly(mtcars, x = vs, type = "bar")
plotly_POST(p, filename = "mtcars-bar-plot")

Run the code above in your browser using DataLab