filename
character string describing the name of the plot in your
plotly account. Use / to specify directories. If a directory path does not
exist it will be created. If this argument is not specified and the title
of the plot exists, that will be used for the
fileopt
character string describing whether to create a "new" plotly,
"overwrite" an existing plotly, "append" data to existing plotly,
or "extend" it.
sharing
If 'public', anyone can view this graph. It will appear in
your profile and can appear in search engines. You do not need to be
logged in to Plotly to view this chart.
If 'private', only you can view this plot. It will not appear in the
Plotly feed, your